washloop

package
v0.0.0-...-3b50903 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 2, 2019 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Motion

type Motion struct {
	Acceleration    washout.Vector
	AngularVelocity washout.Vector
}

A Motion is accelerations and angular velocities in 3D axis.

type WashoutInterface

type WashoutInterface interface {
	Filter(
		accelerationX, accelerationY, accelerationZ,
		angularVelocityX, angularVelocityY, angularVelocityZ float64) washout.Position
}

A WashoutInterface is a interface of washout.

type WashoutLoop

type WashoutLoop struct {
	// contains filtered or unexported fields
}

A WashoutLoop is a loop for process of washout.

func NewWashLoop

func NewWashLoop(washout WashoutInterface, interval uint) *WashoutLoop

NewWashLoop creates new washout loop.

func (*WashoutLoop) GetPosition

func (w *WashoutLoop) GetPosition() washout.Position

GetPosition gets a position as output of washout.

func (*WashoutLoop) SetMotion

func (w *WashoutLoop) SetMotion(motion Motion)

SetMotion sets a motion used as input of washout.

func (*WashoutLoop) Start

func (w *WashoutLoop) Start()

Start starts a loop of process.

func (*WashoutLoop) Stop

func (w *WashoutLoop) Stop()

Stop stops a loop of process.

Jump to